==> percona-server-mongodb_5.0.11.orig.tar.gz: percona-server-mongodb-5.0.11-10/src/mongo/db/encryption/encryption_kmip.h <==
/*======
This file is part of Percona Server for MongoDB.

Copyright (C) 2019-present Percona and/or its affiliates. All rights reserved.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the Server Side Public License, version 1,
    as published by MongoDB, Inc.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Server Side Public License for more details.

    You should have received a copy of the Server Side Public License
    along with this program. If not, see
    <http://www.mongodb.com/licensing/server-side-public-license>.

    As a special exception, the copyright holders give permission to link the
    code of portions of this program with the OpenSSL library under certain
    conditions as described in each individual source file and distribute
    linked combinations including the program with the OpenSSL library. You
    must comply with the Server Side Public License in all respects for
    all of the code used other than as permitted herein. If you modify file(s)
    with this exception, you may extend this exception to your version of the
    file(s), but you are not obligated to do so. If you do not wish to do so,
    delete this exception statement from your version. If you delete this
    exception statement from all source files in the program, then also delete
    it in the license file.
======= */

#pragma once

#include <string>

namespace mongo {

/// @brief Reads a key from the KMIP server specified in the configuration
///
/// @param keyId Identifier of the key to read
///
/// @returns Key data if the reading succeeds or an empty string if no key data
///     is associated with the key identifier
///
/// @throws std::runtime_error if the server can't connect to any of the KMIP
///     servers listed in the configuration
std::string kmipReadKey(const std::string& keyId);

/// @brief Writes the key to the KMIP server specified in the configuration.
///
/// @param keyData The key data, should be base64-encoded
///
/// @returns Key identifier if the writing succeeds or an empty string otherwise.
///
/// @throws std::runtime_error if the server can't connect to any of the KMIP
///     servers listed in the configuration
std::string kmipWriteKey(std::string const& keyData);

}  // namespace mongo

==> percona-server-mongodb_6.0.6.orig.tar.gz: percona-server-mongodb-6.0.6-5/src/mongo/db/encryption/encryption_kmip.h <==
/*======
This file is part of Percona Server for MongoDB.

Copyright (C) 2019-present Percona and/or its affiliates. All rights reserved.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the Server Side Public License, version 1,
    as published by MongoDB, Inc.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Server Side Public License for more details.

    You should have received a copy of the Server Side Public License
    along with this program. If not, see
    <http://www.mongodb.com/licensing/server-side-public-license>.

    As a special exception, the copyright holders give permission to link the
    code of portions of this program with the OpenSSL library under certain
    conditions as described in each individual source file and distribute
    linked combinations including the program with the OpenSSL library. You
    must comply with the Server Side Public License in all respects for
    all of the code used other than as permitted herein. If you modify file(s)
    with this exception, you may extend this exception to your version of the
    file(s), but you are not obligated to do so. If you do not wish to do so,
    delete this exception statement from your version. If you delete this
    exception statement from all source files in the program, then also delete
    it in the license file.
======= */

#pragma once

#include <cstdint>
#include <string>
#include <vector>

/// The code in this namespace is not intended to be called from outside
/// the `mongo::encryption` namespace
namespace mongo::encryption::detail {

/// @brief Reads a key from the KMIP server specified in the configuration
///
/// @param keyId Identifier of the key to read
///
/// @returns Key data if the reading succeeds or an empty vector if no key data
///     is associated with the key identifier
///
/// @throws std::runtime_error if the server can't connect to any of the KMIP
///     servers listed in the configuration
std::vector<std::uint8_t> kmipReadKey(const std::string& keyId);

/// @brief Writes the key to the KMIP server specified in the configuration.
///
/// @param keyData The key data
///
/// @returns Key identifier if the writing succeeds or an empty string otherwise.
///
/// @throws std::runtime_error if the server can't connect to any of the KMIP
///     servers listed in the configuration
std::string kmipWriteKey(const std::vector<std::uint8_t>& keyData);

}  // namespace mongo::encryption::detail
